#!/bin/bash

#This script checks that the installed version of ImageMagick (notably "stream") has been compuled with the correct option for 32-bit integers.
#It looks at the default 'stream' in the PATH, which is probably /usr/local/bin/stream, rather than the distro-provided package.
#The option should be ./configure --with-quantum-depth=32. If not, there will be much weeping and gnashing of teeth...

#NOTE: another way to do this is to look at the version string. For example:  "Version: ImageMagick 6.6.1-10 2011-03-28 Q32 http://www.imagemagick.org"
#This contains either Q16 or Q32.

WHITE_TIFF=../examples/white.tiff	#Test file, created by gencamtest --white white.cam && cam2tiff white.cam white.tiff
EXPECTED_PIXEL_VALUE="00ffffff";	#Pixel value in top left, known to be ffffff00 (but reversed order for little-endian).

echo "Checking that 'stream' and 'display' are built with 32-bit quantum-depth..."


#Check file exists.
white_tiff=`dirname $0`/$WHITE_TIFF
if [ ! -f $white_tiff ]; then
	echo "Error: test file '$white_tiff' does not exist. Please re-run 'make'."
	exit 1
fi

#Check the binary, stream is present.
#Annoyingly, some systems have /usr/bin before /usr/local/bin in path for root. Correct this here.
if [[ ! "$PATH" =~ /usr/local/bin:.*/usr/bin ]] ;then
        export PATH=/usr/local/bin:$PATH
fi
stream=`which stream`
if [ $? != 0 ];	then
	echo "Error: the program 'stream' (part of ImageMagick) is not installed in \$PATH."
	exit 1
fi


#Read the value of the top left pixel from the image, in 32 bits. Pass it to xxd to be printed (little-endian, i.e. backwards). Expect 00ffffff.
pixel_value=`$stream -storage-type integer -colorspace gray -depth 32 -map i -extract 1x1+0+0 $white_tiff - | xxd -p`

if [ "$pixel_value" == "$EXPECTED_PIXEL_VALUE" ];then
	echo "OK: stream ($stream) does support 32-bit quantum depth."
	exit 0
else
	echo "Expected top-left pixel of '$white_tiff' to read as '$EXPECTED_PIXEL_VALUE', but installed version of stream ('$stream') misreads it as '$pixel_value'."
	echo "Error: stream ($stream) does not support 32-bit quantum depth. Rebuild ImageMagick using './configure --with-quantum-depth=32'."
	echo "[This usually means that the distribution-provided 'stream' is 16-bit, and there is no /usr/local/bin/stream, which you should compile.]"
	exit 1
fi
